@@ -44,28 +44,35 @@ class ManageModulesUserView(View):
         if not self.read_only:
             modals = ["core_parser_app/common/modals/add_module.html"]
             assets["js"].append(
-                {"path": "core_parser_app/common/js/module_manager.js", "is_raw": False}
+                {
+                    "path": "core_parser_app/common/js/module_manager.js",
+                    "is_raw": False,
+                }
             )
 
         try:
+            # Build context
+            context = get_context(
+                pk,
+                self.back_to_previous_url,
+                self.read_only,
+                self.title,
+                request=request,
+            )
+            # Set page title
+            context.update({"page_title": "Modules"})
             return render(
                 request,
                 "core_parser_app/common/module_manager.html",
                 modals=modals,
                 assets=assets,
-                context=get_context(
-                    pk,
-                    self.back_to_previous_url,
-                    self.read_only,
-                    self.title,
-                    request=request,
-                ),
+                context=context,
             )
         except Exception as exception:
             return render(
                 request,
                 "core_main_app/common/commons/error.html",
-                context={"error": str(exception)},
+                context={"error": str(exception), "page_title": "Error"},
             )
 
 
@@ -91,7 +98,8 @@ def get_context(template_id, url_previous_button, read_only, title, request):
     # reverse url
     try:
         url_back_to = reverse(
-            url_previous_button, kwargs={"version_manager_id": version_manager.id}
+            url_previous_button,
+            kwargs={"version_manager_id": version_manager.id},
         )
     except NoReverseMatch:
         url_back_to = reverse(url_previous_button)
